@@ -1,11 +1,15 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 from .collect_env import collect_env
+from .compat_config import compat_cfg
 from .logger import get_caller_name, get_root_logger, log_img_scale
 from .misc import find_latest_checkpoint, update_data_root
 from .setup_env import setup_multi_processes
+from .split_batch import split_batch
+from .util_distribution import build_ddp, build_dp, get_device
 
 __all__ = [
     'get_root_logger', 'collect_env', 'find_latest_checkpoint',
     'update_data_root', 'setup_multi_processes', 'get_caller_name',
-    'log_img_scale'
+    'log_img_scale', 'compat_cfg', 'split_batch', 'build_ddp', 'build_dp',
+    'get_device'
 ]
